@charset "Shift_JIS";

/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is the Takahashi-Method-based Presentation Tool
 * in XUL/Returns.
 *
 * The Initial Developer of the Original Code is SHIMODA Hiroshi.
 * Portions created by the Initial Developer are Copyright (C) 2005
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): SHIMODA Hiroshi <piro@p.club.ne.jp>
 *
 * ***** END LICENSE BLOCK ***** */

@namespace url(http://www.mozilla.org/keymaster/gatekeeper/there.is.only.xul);
@namespace html url(http:/www.w3.org/1999/xhtml);

#canvas {
	background: white !important;
	color: black !important;
	font-family:
		"僑僔僢僋MB101U"
		"僯儏乕僙僓儞僰-EB"
		"僙僓儞僰-EB"
		"俢俫俹嬌懢僑僔僢僋懱"
		"俢俥俹嬌懢僑僔僢僋懱"
		"DHPGothic UB"
		"DFPGothic UB"
		"俢俫俹摿懢僑僔僢僋懱"
		"俢俥俹摿懢僑僔僢僋懱"
		"DHPGothic EB"
		"DFPGothic EB"
		"僙僀價僀僒儔僑UB-P"
		"AR P僑僔僢僋懱 S"
		"Arphic PGothic SuperBold JIS"
/*		"Arial Black"*/
		"俢俥摿懢僑僔僢僋懱"
		"DFGothic EB"
		"僙僀價僀僒儔僑UB"
		"AR 僑僔僢僋懱 S"
		"Arphic Gothic SuperBold JIS"
		"HGP憂塸妏恨集窾B"
		"HGPSoeiKakugothicUB"
		"HGS憂塸妏恨集窾B"
		"HG憂塸妏恨集窾B"
		"HGSoeiKakugothicUB"
		"彫捤僑僔僢僋 Std H"
		"儌僩儎僑僔僢僋 6"
		sans-serif !important;
}

.em-text {
	color: red !important;
	font-size: 120%;
}

.link-text {
	color: blue !important;
	text-decoration: underline !important;
}
.link-text:hover {
	color: #3366FF !important;
}
.link-text:active {
	color: red !important;
}

.preformatted-text.block {
	border: 1px dashed gray;
	padding: 0.3em;
	margin: 0.3em;
	font-size: 80%;
}

.monta-label {
	background-color: white;
	background-repeat: no-repeat;
	background-image: url(./monta-label.png);
}



#header,
#footer {
	color: #666;
}


/* Eva Mode */

#canvas[eva="true"] {
	background: black !important;
	color: white !important;
	font-family:
		"儕儏僂儈儞U-KL"
		"儕儏僂儈儞H-KL"
		"儅僥傿僗-EB"
		"RF僼傽僀儞-ME"
		"俢俫俹嬌懢柧挬懱"
		"俢俥俹嬌懢柧挬懱"
		"DHPMincho UB"
		"DFPMincho UB"
		"AR P柧挬懱U"
		"Arphic PMincho Ultra JIS"
		"AR柧挬懱U"
		"Arphic Mincho Ultra JIS"
		"HGP暯惉柧挬懱W9"
		"HGPHeiseiMinchotaiW9"
		"HGS暯惉柧挬懱W9"
		"HGSHeiseiMinchotaiW9"
		"HG暯惉柧挬懱W9"
		"HGHeiseiMinchotaiW9"
		serif !important;
}
#canvas[eva="true"] .em-text {
	color: green !important;
}
#canvas[eva="true"] .link-text {
	color: red !important;
	text-decoration: none !important;
}
#canvas[eva="true"] .link-text:hover {
	color: pink !important;
}
#canvas[eva="true"] .link-text:active {
	color: orange !important;
}

#canvas[eva="true"] #header,
#canvas[eva="true"] #footer {
	color: #AAA;
}


#canvas[eva="true"] .monta-label {
	background-color: black;
}





.stroke-dot {
	background: red;
	width: 3px;
	height: 3px;
}








/* System:: DO NOT CHANGE FOLLOWING LINES!! */


#canvas * {
	cursor: pointer !important;
}

#canvas image {
	width: auto;
	height: auto;
}
#canvas[rendering="true"] image {
	display: none;
}

#canvas[rendering="true"] *,
#canvas[rendering="true"] .text-link {
	color: inherit !important;
}

#canvas[rendering="true"] #contentBox {
	visibility: hidden;
}






.preformatted-text {
	font-family: -moz-fixed !important;
	white-space: pre !important;
}




tabbox, tabpanels, tabpanel {
	margin: 0;
	padding: 0;
}


.dropmarker-button > image {
	display: none !important;
}
.dropmarker-button > label {
	width: 0 !important;
	overflow: hidden !important;
}

#pages-list-button menupopup {
	max-width: 20em;
}
#pages-list-button menuitem image {
	max-width: 32px;
	max-height: 32px;
}




#headerBox,
#footerBox {
	margin: 1em;
}




.monta-label {
	padding: 0.05em;
	margin: -0.05em;
}
.monta-label[monta-hidden="true"],
.monta-label[monta-hidden="progress"] {
	background-position: -100px 0;
}
.monta-label[monta-hidden="progress"] {
	background-color: transparent;
}
.monta-label[monta-hidden="false"] {
	background: transparent !important;
}




#canvasToolbar {
	position: relative;
	z-index: 1000;
}

#textField {
	font-family: -moz-fixed !important;
}





#stroke-canvas-box {
	position: relative;
	display: block;
}
#stroke-canvas-box *|canvas {
	width: 100%;
	height: 100%;
}

.stroke-dot {
	position: absolute;
	display: block;
	z-index: 100;
}
